@@ -3,13 +3,13 @@ package HTML::FormHandlerX::Widget::Field::noCAPTCHA;
 use Moose::Role;
 use namespace::autoclean;
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 sub render_element { return shift->_nocaptcha->html; }
 
 sub render {
 	my ( $self, $result ) = @_;
-	return '' unless ($result);
+	$result ||= $self->result;
 	my $output = $self->_nocaptcha->html;
 	return $self->wrap_field( $result, $output );
 }
